@@ -31,7 +31,10 @@ def decode_data(response_content, data_type):
     :raises: ValueError
     """
     if data_type is MimeType.JSON:
-        return json.loads(response_content.decode('utf-8'))
+        response_text = response_content.decode('utf-8')
+        if not response_text:
+            return response_text
+        return json.loads(response_text)
     if data_type is MimeType.TAR:
         return decode_tar(response_content)
     if MimeType.is_image_format(data_type):
@@ -46,8 +49,8 @@ def decode_data(response_content, data_type):
             MimeType.TXT: response_content,
             MimeType.ZIP: BytesIO(response_content)
         }[data_type]
-    except KeyError:
-        raise ValueError('Unknown response data type {}'.format(data_type))
+    except KeyError as exception:
+        raise ValueError('Unknown response data type {}'.format(data_type)) from exception
 
 
 def decode_image(data, image_type):
@@ -150,9 +153,9 @@ def fix_jp2_image(image, bit_depth):
     if bit_depth == 15:
         try:
             return image >> 1
-        except TypeError:
+        except TypeError as exception:
             raise IOError('Failed to read JPEG 2000 image correctly. Most likely reason is that Pillow did not '
-                          'install OpenJPEG library correctly. Try reinstalling Pillow from a wheel')
+                          'install OpenJPEG library correctly. Try reinstalling Pillow from a wheel') from exception
 
     raise ValueError('Bit depth {} of jp2 image is currently not supported. '
                      'Please raise an issue on package Github page'.format(bit_depth))
