@@ -8,11 +8,12 @@ from urllib.parse import urlencode
 
 import shapely.geometry
 
-from .constants import ServiceType, DataSource, MimeType, CRS, SHConstants, CustomUrlParam
+from .constants import ServiceType, MimeType, CRS, SHConstants, CustomUrlParam
 from .config import SHConfig
+from .data_collections import DataCollection, handle_deprecated_data_source
 from .geo_utils import get_image_dimension
 from .geometry import BBox, Geometry
-from .download import DownloadRequest, get_json
+from .download import DownloadRequest, SentinelHubDownloadClient
 from .time_utils import parse_time_interval, filter_times
 
 LOGGER = logging.getLogger(__name__)
@@ -34,24 +35,6 @@ class OgcService:
                              'Set it either in request initialization or in configuration file. '
                              'Check http://sentinelhub-py.readthedocs.io/en/latest/configure.html for more info.')
 
-    @staticmethod
-    def _sentinel1_product_check(product_id, data_source):
-        """ Checks if Sentinel-1 product ID matches Sentinel-1 DataSource configuration
-
-        :param product_id: Sentinel-1 product ID
-        :type product_id: str
-        :param data_source: One of the supported Sentinel-1 data sources
-        :type data_source: constants.DataSource
-        :return: `True` if data_source contains product_id and `False` otherwise
-        :rtype: bool
-        """
-        props = product_id.split('_')
-        acquisition, resolution, polarisation = props[1], props[2][3], props[3][2:4]
-        if acquisition in ['IW', 'EW'] and resolution in ['M', 'H'] and polarisation in ['DV', 'DH', 'SV', 'SH']:
-            return acquisition == data_source.value[2].name and polarisation == data_source.value[3].name and \
-                   resolution == data_source.value[4].name[0]
-        raise ValueError('Unknown Sentinel-1 tile type: {}'.format(product_id))
-
 
 class OgcImageService(OgcService):
     """Sentinel Hub OGC services class for providing image data
@@ -124,15 +107,10 @@ class OgcImageService(OgcService):
         :rtype: str
         """
         url = '{}/{}'.format(self._base_url, request.service_type.value)
-        # These 2 lines are temporal and will be removed after the use of uswest url wont be required anymore:
-        if hasattr(request, 'data_source') and request.data_source.is_uswest_source(config=self.config):
-            url = 'https://services-uswest2.sentinel-hub.com/ogc/{}'.format(request.service_type.value)
 
-        if hasattr(request, 'data_source') and \
-                request.data_source not in DataSource.get_available_sources(config=self.config):
-            raise ValueError("{} is not available for service at service available at {}. Try"
-                             "changing 'sh_base_url' parameter in package configuration "
-                             "file".format(request.data_source, SHConfig().get_sh_ogc_url()))
+        if hasattr(request, 'data_collection') and request.data_collection.service_url:
+            url = url.replace(self.config.sh_base_url, request.data_collection.service_url)
+
         return url
 
     @staticmethod
@@ -299,11 +277,11 @@ class OgcImageService(OgcService):
         :return: List of dates of existing acquisitions for the given request
         :rtype: list(datetime.datetime) or [None]
         """
-        if DataSource.is_timeless(request.data_source):
+        if request.data_collection.is_timeless:
             return [None]
 
         if request.wfs_iterator is None:
-            self.wfs_iterator = WebFeatureService(request.bbox, request.time, data_source=request.data_source,
+            self.wfs_iterator = WebFeatureService(request.bbox, request.time, data_collection=request.data_collection,
                                                   maxcc=request.maxcc, config=self.config)
         else:
             self.wfs_iterator = request.wfs_iterator
@@ -339,7 +317,7 @@ class OgcImageService(OgcService):
         """ Returns iterator over info about all satellite tiles used for the request
 
         :return: Iterator of dictionaries containing info about all satellite tiles used in the request. In case of
-                 DataSource.DEM it returns None.
+                 DataCollection.DEM it returns None.
         :rtype: Iterator[dict] or None
         """
         return self.wfs_iterator
@@ -352,25 +330,28 @@ class WebFeatureService(OgcService):
     from Sentinel Hub service only during the first iteration. During next iterations it returns already obtained data.
     The data is in the order returned by Sentinel Hub WFS service.
     """
-    def __init__(self, bbox, time_interval, *, data_source=DataSource.SENTINEL2_L1C, maxcc=1.0, **kwargs):
+    def __init__(self, bbox, time_interval, *, data_collection=None, maxcc=1.0, data_source=None, **kwargs):
         """
         :param bbox: Bounding box of the requested image. Coordinates must be in the specified coordinate reference
             system.
         :type bbox: geometry.BBox
         :param time_interval: interval with start and end date of the form YYYY-MM-DDThh:mm:ss or YYYY-MM-DD
         :type time_interval: (str, str)
-        :param data_source: Source of requested satellite data. Default is Sentinel-2 L1C data.
-        :type data_source: constants.DataSource
+        :param data_collection: A collection of requested satellite data
+        :type data_collection: DataCollection
         :param maxcc: Maximum accepted cloud coverage of an image. Float between 0.0 and 1.0. Default is 1.0.
         :type maxcc: float
         :param config: A custom instance of config class to override parameters from the saved configuration.
         :type config: SHConfig or None
+        :param data_source: A deprecated alternative to data_collection
+        :type data_source: DataCollection
         """
         super().__init__(**kwargs)
 
         self.bbox = bbox
         self.time_interval = parse_time_interval(time_interval)
-        self.data_source = data_source
+        self.data_collection = DataCollection(handle_deprecated_data_source(data_collection, data_source,
+                                                                            default=DataCollection.SENTINEL2_L1C))
         self.maxcc = maxcc
 
         self.tile_list = []
@@ -379,6 +360,9 @@ class WebFeatureService(OgcService):
         self.latest_time_only = time_interval == SHConstants.LATEST
         self.max_features_per_request = 1 if self.latest_time_only else SHConfig().max_wfs_records_per_query
 
+        if self.data_collection.service_url:
+            self._base_url = self._base_url.replace(self.config.sh_base_url, self.data_collection.service_url)
+
     def __iter__(self):
         """ Iteration method
 
@@ -415,7 +399,7 @@ class WebFeatureService(OgcService):
             'SERVICE': ServiceType.WFS.value,
             'WARNINGS': False,
             'REQUEST': 'GetFeature',
-            'TYPENAMES': DataSource.get_wfs_typename(self.data_source, config=self.config),
+            'TYPENAMES': self.data_collection.wfs_id,
             'BBOX': str(self.bbox.reverse()) if self.bbox.crs is CRS.WGS84 else str(self.bbox),
             'OUTPUTFORMAT': MimeType.get_string(MimeType.JSON),
             'SRSNAME': CRS.ogc_string(self.bbox.crs),
@@ -428,18 +412,15 @@ class WebFeatureService(OgcService):
         url = main_url + urlencode(params)
 
         LOGGER.debug("URL=%s", url)
-        response = get_json(url)
+        client = SentinelHubDownloadClient(config=self.config)
+        response = client.get_json(url)
 
-        is_sentinel1 = self.data_source.is_sentinel1()
-        for tile_info in response["features"]:
-            if is_sentinel1:
-                if self._sentinel1_product_check(tile_info['properties']['id'], self.data_source) and \
-                        self.data_source.contains_orbit_direction(tile_info['properties']['orbitDirection']):
-                    self.tile_list.append(tile_info)
-            else:
+        is_sentinel1 = self.data_collection.is_sentinel1
+        for tile_info in response['features']:
+            if not is_sentinel1 or self._sentinel1_product_check(tile_info):
                 self.tile_list.append(tile_info)
 
-        if len(response["features"]) < self.max_features_per_request or self.latest_time_only:
+        if len(response['features']) < self.max_features_per_request or self.latest_time_only:
             self.feature_offset = None
         else:
             self.feature_offset += self.max_features_per_request
@@ -453,7 +434,7 @@ class WebFeatureService(OgcService):
         tile_dates = []
 
         for tile_info in self:
-            if not tile_info['properties']['date']:  # could be True for custom (BYOC) data sources
+            if not tile_info['properties']['date']:  # could be True for custom (BYOC) data collections
                 tile_dates.append(None)
             else:
                 tile_dates.append(datetime.datetime.strptime('{}T{}'.
@@ -490,3 +471,19 @@ class WebFeatureService(OgcService):
         """
         props = tile_url.rsplit('/', 7)
         return ''.join(props[1:4]), '-'.join(props[4:7]), int(props[7])
+
+    def _sentinel1_product_check(self, tile_info):
+        """ Checks if Sentinel-1 tile info match the data collection definition
+        """
+        product_id = tile_info['properties']['id']
+        props = product_id.split('_')
+        swath_mode, resolution, polarization = props[1], props[2][3], props[3][2:4]
+        orbit_direction = tile_info['properties'].get('orbitDirection', '')
+
+        if not (swath_mode in ['IW', 'EW'] and resolution in ['M', 'H'] and polarization in ['DV', 'DH', 'SV', 'SH']):
+            raise ValueError(f'Unknown Sentinel-1 tile type: {product_id}')
+
+        return (swath_mode == self.data_collection.swath_mode or self.data_collection.swath_mode is None) \
+            and (polarization == self.data_collection.polarization or self.data_collection.polarization is None) \
+            and (resolution == self.data_collection.resolution[0] or self.data_collection.resolution is None) \
+            and self.data_collection.contains_orbit_direction(orbit_direction)
